pub trait Association<T> {
// Required methods
fn loaded_child(&mut self, child: T);
fn assert_loaded_otherwise_failed(&mut self);
}Expand description
Methods available for all association types.
Required Methods
Sourcefn loaded_child(&mut self, child: T)
fn loaded_child(&mut self, child: T)
Store the loaded child on the association.
Sourcefn assert_loaded_otherwise_failed(&mut self)
fn assert_loaded_otherwise_failed(&mut self)
The association should have been loaded by now, if not store an error inside the association (if applicable for the particular association).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".